package de.laliluna.tutorial.customconverter.converter;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.faces.application.FacesMessage;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;

/**
 * Converter class TextConverter
 */
public class CreditCardConverter implements Converter{
	
	public final static String CONVERTER_ID = "laliluna.CreditCard";

	private String displayCharacter;
	
	public String getDisplayCharacter() {
		return displayCharacter;
	}
	public void setDisplayCharacter(String displayCharacter) {
		this.displayCharacter = displayCharacter;
	}
	
	/**
	 * Convert from String into Object
	 */
	public Object getAsObject(FacesContext context, 
							  UIComponent component, 
							  String string) throws ConverterException {
		
		Long lValue = null;
	
		//check the string with regular expression
		Pattern pattern = Pattern.compile("[0-9]{4}" + 
							displayCharacter + "[0-9]{5}" + 
							displayCharacter + "[0-9]{3}");
		Matcher matcher = pattern.matcher(string);
		
		if(matcher.matches()){
			//replace the characters and convert the String into a Long 
			lValue = Long.valueOf(string.replaceAll(displayCharacter, ""));
		}else{
			//if string do not match the regular expression
			//throw a converter exception
			throw new ConverterException(
					new FacesMessage("Conversion into object failed, credit card number incorrect"));	
		}		
		
		return lValue;
	}
	
	/**
	 * Convert from Object into String
	 */
	public String getAsString(FacesContext context, 
							  UIComponent component, 
							  Object object) throws ConverterException {
		
		String sValue = object.toString();
		
		if(sValue.length() == 12){
			//format the returned String object
			sValue = sValue.substring(0, 4) + displayCharacter + 
					 sValue.substring(4, 9) + displayCharacter + 
					 sValue.substring(9, 12);
		} else {
			throw new ConverterException(
					new FacesMessage("Conversion into string failed, credit card number incorrect"));
		}
		
		return sValue;
	}
}
